==> nextcloud-28.0.14.tgz: nextcloud/apps/twofactor_totp/l10n/es_EC.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Habilitaste la autenticación TOTP de dos factores en tu cuenta",
    "You disabled TOTP two-factor authentication for your account" : "Deshabilitaste la autenticación de dos factores TOTP para tu cuenta.",
    "TOTP two-factor authentication disabled by an admin" : "La autenticación de dos factores TOTP ha sido desactivada por un administrador",
    "TOTP (Authenticator app)" : "TOTP (aplicación de autenticador)",
    "Authenticate with a TOTP app" : "Autenticar con una aplicación TOTP",
    "Two-Factor TOTP Provider" : "Proveedor de autenticación de dos factores TOTP",
    "TOTP two-factor provider" : "Proveedor de dos factores TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un proveedor de autenticación de dos factores para TOTP (RFC 6238)",
    "Enable TOTP" : "Habilitar TOTP",
    "Could not enable TOTP" : "No se pudo habilitar TOTP",
    "Could not verify your key. Please try again" : "No fue posible verificar tu llave. Por favor vuelve a intentarlo",
    "Your new TOTP secret is:" : "Tu nuevo secreto TOTP es:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para una configuración rápida, escanea este código QR con tu aplicación TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Después de configurar tu aplicación, ingresa un código de prueba a continuación para asegurarte de que todo funcione correctamente:",
    "Authentication code" : "Código de autenticación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obten el código de autenticación de la aplicación de autenticación de dos factores en tu dispositivo.",
    "Submit" : "Enviar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/es_EC.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Habilitaste la autenticación TOTP de dos factores en tu cuenta",
    "You disabled TOTP two-factor authentication for your account" : "Deshabilitaste la autenticación de dos factores TOTP para tu cuenta.",
    "TOTP (Authenticator app)" : "TOTP (aplicación de autenticador)",
    "Authenticate with a TOTP app" : "Autenticar con una aplicación TOTP",
    "Two-Factor TOTP Provider" : "Proveedor de autenticación de dos factores TOTP",
    "Enable TOTP" : "Habilitar TOTP",
    "Could not enable TOTP" : "No se pudo habilitar TOTP",
    "Could not verify your key. Please try again" : "No fue posible verificar tu llave. Por favor vuelve a intentarlo",
    "Your new TOTP secret is:" : "Tu nuevo secreto TOTP es:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para una configuración rápida, escanea este código QR con tu aplicación TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Después de configurar tu aplicación, ingresa un código de prueba a continuación para asegurarte de que todo funcione correctamente:",
    "Authentication code" : "Código de autenticación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obten el código de autenticación de la aplicación de autenticación de dos factores en tu dispositivo.",
    "Submit" : "Enviar",
    "TOTP two-factor authentication disabled by an admin" : "La autenticación de dos factores TOTP ha sido desactivada por un administrador",
    "TOTP two-factor provider" : "Proveedor de dos factores TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un proveedor de autenticación de dos factores para TOTP (RFC 6238)"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
